==> cloudsnorkel.cdk-github-runners-0.0.2.tar.gz: package/lib/providers/codebuild.d.ts <==
import { Duration, aws_codebuild as codebuild, aws_ec2 as ec2, aws_iam as iam, aws_stepfunctions as stepfunctions } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { IRunnerProvider, RunnerProviderProps, RunnerRuntimeParameters } from './common';
export interface CodeBuildRunnerProps extends RunnerProviderProps {
    /**
     * GitHub Actions label used for this provider.
     *
     * @default 'codebuild'
     */
    readonly label?: string;
    /**
     * VPC to launch the runners in.
     *
     * @default no VPC
     */
    readonly vpc?: ec2.IVpc;
    /**
     * Security Group to assign to this instance.
     *
     * @default public project with no security group
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * Where to place the network interfaces within the VPC.
     *
     * @default no subnet
     */
    readonly subnetSelection?: ec2.SubnetSelection;
    /**
     * The type of compute to use for this build.
     * See the {@link ComputeType} enum for the possible values.
     *
     * @default {@link ComputeType#SMALL}
     */
    readonly computeType?: codebuild.ComputeType;
    /**
     * The number of minutes after which AWS CodeBuild stops the build if it's
     * not complete. For valid values, see the timeoutInMinutes field in the AWS
     * CodeBuild User Guide.
     *
     * @default Duration.hours(1)
     */
    readonly timeout?: Duration;
}
/**
 * GitHub Actions runner provider using CodeBuild to execute the actions.
 *
 * Creates a project that gets started for each job.
 */
export declare class CodeBuildRunner extends Construct implements IRunnerProvider {
    readonly project: codebuild.Project;
    readonly label: string;
    readonly vpc?: ec2.IVpc;
    readonly securityGroup?: ec2.ISecurityGroup;
    readonly grantPrincipal: iam.IPrincipal;
    constructor(scope: Construct, id: string, props: CodeBuildRunnerProps);
    getStepFunctionTask(parameters: RunnerRuntimeParameters): stepfunctions.IChainable;
    get connections(): ec2.Connections;
}
//# sourceMappingURL=codebuild.d.ts.map

==> cloudsnorkel.cdk-github-runners-0.0.14.tar.gz: package/lib/providers/codebuild.d.ts <==
import { Duration, aws_codebuild as codebuild, aws_ec2 as ec2, aws_iam as iam, aws_stepfunctions as stepfunctions } from 'aws-cdk-lib';
import { Construct } from 'constructs';
import { IRunnerProvider, RunnerProviderProps, RunnerRuntimeParameters } from './common';
export interface CodeBuildRunnerProps extends RunnerProviderProps {
    /**
     * GitHub Actions label used for this provider.
     *
     * @default 'codebuild'
     */
    readonly label?: string;
    /**
     * VPC to launch the runners in.
     *
     * @default no VPC
     */
    readonly vpc?: ec2.IVpc;
    /**
     * Security Group to assign to this instance.
     *
     * @default public project with no security group
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * Where to place the network interfaces within the VPC.
     *
     * @default no subnet
     */
    readonly subnetSelection?: ec2.SubnetSelection;
    /**
     * The type of compute to use for this build.
     * See the {@link ComputeType} enum for the possible values.
     *
     * @default {@link ComputeType#SMALL}
     */
    readonly computeType?: codebuild.ComputeType;
    /**
     * The number of minutes after which AWS CodeBuild stops the build if it's
     * not complete. For valid values, see the timeoutInMinutes field in the AWS
     * CodeBuild User Guide.
     *
     * @default Duration.hours(1)
     */
    readonly timeout?: Duration;
}
/**
 * GitHub Actions runner provider using CodeBuild to execute the actions.
 *
 * Creates a project that gets started for each job.
 *
 * This construct is not meant to be used by itself. It should be passed in the providers property for GitHubRunners.
 */
export declare class CodeBuildRunner extends Construct implements IRunnerProvider {
    /**
     * CodeBuild project hosting the runner.
     */
    readonly project: codebuild.Project;
    /**
     * Label associated with this provider.
     */
    readonly label: string;
    /**
     * VPC used for hosting the project.
     */
    readonly vpc?: ec2.IVpc;
    /**
     * Security group attached to the task.
     */
    readonly securityGroup?: ec2.ISecurityGroup;
    /**
     * Grant principal used to add permissions to the runner role.
     */
    readonly grantPrincipal: iam.IPrincipal;
    constructor(scope: Construct, id: string, props: CodeBuildRunnerProps);
    /**
     * Generate step function task(s) to start a new runner.
     *
     * Called by GithubRunners and shouldn't be called manually.
     *
     * @param parameters workflow job details
     */
    getStepFunctionTask(parameters: RunnerRuntimeParameters): stepfunctions.IChainable;
    /**
     * The network connections associated with this resource.
     */
    get connections(): ec2.Connections;
}
//# sourceMappingURL=codebuild.d.ts.map
